---
title: "Ὅσοι ἄνθρωποι, τοσαῦται γνῶμαι"
subtitle: "Harmonizing Guidelines for Handwritten Text Recognition of Ancient Greek"
content: "DH2025, Lisbon, July 14-18<sup>th</sup>, 2025"
---


{{< blocs/texte-exergue >}}
![](/images/dh25.jpg)
{{< /blocs/texte-exergue >}}

{{< blocs/prose id="introduction" >}}

## A workshop to foster a community of practices and establish guidelines for HTR dedicated to Ancient Greek.

In recent years, there have been significant developments in the field of HTR with the rise of several general public software such as eScriptorium and Transkribus. In conjunction with technological progress, there has been a growing emphasis on the **development of datasets and guidelines** to standardize procedures and thereby facilitate their implementation.

For Latin script manuscripts, a critical mass of data appears to have been reached. However, **non-Latin scripts often remain on the margins** from this progress. Currently, researchers often work on their own, following diverse practices and standards tailored to the needs of their specific projects. This situation mirrors the early days of Latin script HTR, before the development of comprehensive guidelines that slowly gained the potential to transform the field. Similarly, the establishment of **a collaborative and interdisciplinary community could facilitate significant progress in non-Latin script HTR**.

**HTR for Ancient Greek faces several challenges**, including a limited and dispersed corpus compared to Latin scripts, which hinders the development of effective models. Another issue is the lack of consistent encoding practices for Greek paleographic features. While Unicode provides basic characters for the Greek alphabet, it does not account for all the paleographic elements (such as ligatures and abbreviations) found in Ancient Greek manuscripts. This gap has led to varying encoding practices, complicating data standardization and limiting interoperability.

To improve data reuse and collaboration, a more generalized approach is needed, with harmonized practices across projects to enable data aggregation, sharing, and pre-annotation. 

## Goals of this Workshop 

This workshop is not intended to be a technical training session on HTR, but rather a space for **reflection, collaboration, and community building**. It aims to bring together researchers and practitioners from a range of disciplines, including philologists, paleographers, HTR users (across various languages), and dataset creators, to address the technical and methodological challenges that have hindered the development of effective HTR for Ancient Greek. 

The primary goals are:

1. To foster the development of an **interdisciplinary community of practice** that combines complementary expertise to address the challenges posed by the automatic recognition of Greek documents. 
2. To **develop common guidelines** for the transcription and encoding of ancient Greek texts, especially for the training of automatic text recognition models.


## In short 

### Date & Time

14 or 15<sup>th</sup> of July 2025, around 10:00-16:00 [*to be confirmed*]

### Location

NOVA FCSH [*tbc*] 

### Workshop organizers 

- [Mathilde Verstraete (contact person)](mailto:mathilde.verstraete@umontreal.ca) 
- [Maxime Guénette (contact person)](mailto:maxime.guenette@umontreal.ca)
- Malamatenia Vlachou-Efstathiou
- Marianne Reboul
- Marcello Vitali-Rosati

> See also the [Acknowledgements](acknowledgements.md)

## Want to join? 

We welcome anyone interested in (digital) paleography or in developing guidelines for HTR applied to Ancient Greek. However, space may be limited.  

This workshop will be held **in person only**. All registered participants of DH2025 are eligible to apply, but please note that workshop participants must also be registered for DH2025. [See the conference website for details](https://dh2025.adho.org/).  

If you would like to present a case study (10–15 minutes, depending on the number of proposals received), please send us a short description. You can refer to the presentation of [Project #1 as an example](materials.md/#case-study-1---htr-for-codex-palatinus-graecus-23). To apply, please email a **letter of interest** and a **CV** to [Mathilde Verstraete](mailto:mathilde.verstraete@umontreal.ca) and [Maxime Guénette](mailto:maxime.guenette@umontreal.ca).  
 
**Submission deadline: 21 April 2025**.


{{< /blocs/prose>}}


{{< blocs/horaire entete="Schedule (under construction)" id="schedule" >}}

{{< blocs/item-horaire
    heure="10:00-11:00"
    titre="Welcome speech & Introduction"
    personnes="Mathilde Verstraete, Maxime Guénette, Malamatenia Vlachou-Efstathiou & Marianne Reboul"
    resume="Overview of automatic transcription, workshop goals and objectives, and presentation of the organizing team. Presentation of the participants."
>}}

{{< blocs/item-horaire
    heure="11:30-12:30"
    titre="HTR & Ancient Greek ; Preliminary Thoughts on Guidelines"
    personnes="Organizing Team"
    resume="State of the Art – Overview of current challenges and opportunities. Open discussion to identify key considerations"
>}}

{{< blocs/item-horaire
    heure="13:30-15:00"
    titre="[Case Studies] tba."
    personnes="tba."
    resume="[#1 : HTR for Codex Palatinus Graecus 23](materials.md/#case-study-1---htr-for-codex-palatinus-graecus-23)"
>}}

{{< blocs/item-horaire
    heure="15:00-16:00"
    titre="Creating Guidelines."
    personnes="All"
    resume="Discussion of problems explained and possible solutions."
>}}

<!--
{{< blocs/item-horaire
    heure="09:00-09:30"
    titre="Welcome speech & Introduction"
    personnes="Mathilde Verstraete, Maxime Guénette"
    resume="Overview of automatic transcription, workshop goals and objectives, and presentation of the organizing team"
>}}
  
{{< blocs/item-horaire
    heure="9:30-10:00"
    titre="Quick presentation of the participants"
    personnes="Participants"
    resume="Quick presentation from the workshop's participants ; presentation of the goals and expectations"
  >}}

{{< blocs/item-horaire
    heure="10:00-10:30"
    titre="HTR & Ancient Greek"
    personnes="Organizing Team"
    resume="State of the Art – Overview of current challenges and opportunities."
>}}

{{< blocs/item-horaire
    heure="10:30-10:45"
    titre="Preliminary Thoughts on Guidelines"
    personnes="All"
    resume="Open discussion to identify key considerations"
>}}

{{< blocs/item-horaire
    heure="10:45-11:00"
    titre="Break"
>}}

{{< blocs/item-horaire
    heure="11:00-11:15"
    titre="[Case Study] A model for the Codex Palatinus Graecus 23"
    personnes="Maxime Guénette, Mathilde Verstraete"
    resume="To come."
>}}

{{< blocs/item-horaire
    heure="11:15-11:30"
    titre="[Case Study] To come."
    personnes="To come."
    resume="To come."
>}}

{{< blocs/item-horaire
    heure="11:30-11:45"
    titre="[Case Study] To come."
    personnes="To come."
    resume="To come."
>}}

{{< blocs/item-horaire
    heure="11:45-12:00"
    titre="[Case Study] To come."
    personnes="To come."
    resume="To come."
>}}

{{< blocs/item-horaire
    heure="12:00-12:15"
    titre="[Case Study] To come."
    personnes="To come."
    resume="To come."
>}}

{{< blocs/item-horaire
    heure="12:15-12:30"
    titre="[Case Study] To come."
    personnes="To come."
    resume="To come."
>}}

{{< blocs/item-horaire
    heure="12:30-14:00"
    titre="Lunch & Discussion about the projects."
>}}

{{< blocs/item-horaire
    heure="14:00-15:00"
    titre="Creating Guidelines."
    personnes="All"
    resume="Discussion of problems explained and possible solutions."
>}}

{{< blocs/item-horaire
    heure="15:00-15:30"
    titre="Feedback on Guidelines."
    personnes="All"
    resume="Review and draft based on case studies."
>}}

{{< blocs/item-horaire
    heure="15:30-16:00"
    titre="Conclusion."
    personnes="All"
    resume="Summary of outcomes and establishing plans for further collaboration."
>}}
-->
{{< /blocs/horaire >}}

<!--
{{< blocs/partenaires entete="Our Partners" id="partners" >}}

{{< blocs/item-partenaires
    src="/images/partenaires/unimc-logo-transparent.png"
    alt="Università di Macerata"
>}}


{{< blocs/item-partenaires
    src="https://horizons.ecrituresnumeriques.ca/images/Logo/UdeM.png"
    alt="Université de Montréal"
>}}

{{< blocs/item-partenaires
    src="/images/logo-fr.svg"
    alt="Chaire de recherche du Canada sur les écritures numériques"
>}}

{{< blocs/item-partenaires
    src="/images/partenaires/doppio-diploma-v1.png"
    alt="Doppio diploma in Scienze Filosofiche"
>}}

{{< blocs/item-partenaires
    src="/images/partenaires/CRIHN.png"
    alt="Centre de recherche interuniversitaire sur les humanités numériques"
>}}

{{< /blocs/partenaires >}}
-->


